@@ -125,7 +125,6 @@ class SerbCyr:
         "aparthejd",
         "ddor",
         "dss",
-        "džoov",
         "dvadesettrog",
         "epp",
         "fss",
@@ -135,7 +134,6 @@ class SerbCyr:
         "ishod",
         "ishran",
         "izzzdiovns",
-        "jednook",
         "kss",
         "llsls",
         "mmf",
@@ -146,22 +144,16 @@ class SerbCyr:
         "neophod",
         "neshvać",
         "neshvat",
-        "novoosnovan",
-        "novootkriven",
         "obeshrabr",
         "ommetar",
         "opho",
+        "ophrva",
+        "othrama",
         "penthaus",
-        "plavook",
         "poddirektor",
         "poddisciplin",
         "poddomen",
         "poddres",
-        "poobar",
-        "poodmak",
-        "poodras",
-        "pootpa",
-        "pooštr",
         "posthumn",
         "posttrans",
         "posttraum",
@@ -169,21 +161,19 @@ class SerbCyr:
         "pothranj",
         "pothva",
         "preddijabetes",
-        "prekookean",
         "prethod",
         "prevashod",
         "ptt",
         "punkt",
         "rashlad",
         "rashod",
-        "samoodrž",
         "sbb",
         "sdss",
+        "shem", # схема
         "shodno",
         "shvać",
         "shvat",
         "skocka",
-        "slepoo",
         "ssp",
         "ssrnj",
         "sssr",
@@ -268,6 +258,7 @@ class SerbCyr:
         "printscreen",
         "procredit",
         "project",
+        "prslook",
         "punk",
         "renault",
         "rock",
@@ -317,6 +308,7 @@ class SerbCyr:
         "home",
         "ii",
         "iii",
+        "iv",
         "idj",
         "idjtv",
         "life",
@@ -331,6 +323,7 @@ class SerbCyr:
         "reserved",
         "terms",
         "url",
+        "v", # In Serbian language this is not a word, unlike in Russian
         "vii",
         "viii",
         "visa"
@@ -370,11 +363,11 @@ class SerbCyr:
         '&',
         '@',
         '#',
-        'ae',
         'bb',
         'cc',
         'cs',
         'dd',
+        'dh',
         'ee',
         'ff',
         'gg',
@@ -387,8 +380,6 @@ class SerbCyr:
         'mm',
         'nn',
         'ny',
-        'oe',
-        'oo',
         'ph',
         'pp',
         'rr',
